sd_section("Package overview",
  "",
  c(
    "photobiologyWavebands-package"
    )
)

sd_section("Wavelength ranges",
  "Waveband constructors for named wavelength ranges.",
  c(
    "UV",
    "UVC",
    "UVB",
    "UVA",
    "VIS",
    "Purple",
    "Blue",
    "Green",
    "Yellow",
    "Orange",
    "Red",
    "Far_red",
    "IR",
    "PAR"
  )
)

sd_section("Lists of wavebands",
           "Constructors for lists related waveband objects.",
           c(
             "UV_bands",
             "VIS_bands",
             "IR_bands",
             "Plant_bands",
             "Landsat_bands"
           )
)

sd_section("Spectral weighting functions (SWFs)",
           "SWFs and their corresponding waveband constructors",
  c(
    "CIE_e_fun",
    "CIE_q_fun",
    "CIE",
    "UVI",
    "DNA_GM_q_fun",
    "DNA_GM",
    "DNA_P_q_fun",
    "DNA_P",
    "DNA_N_q_fun",
    "DNA_N",
    "FLAV_q_fun",
    "FLAV",
    "GEN_G_q_fun",
    "GEN_G",
    "GEN_T_q_fun",
    "GEN_T",
    "GEN_M_q_fun",
    "GEN_M",
    "PG_q_fun",
    "PG",
    "CH4_e_fun",
    "CH4_q_fun",
    "CH4",
    "ICNIRP_e_fun",
    "ICNIRP"
    )
)

sd_section("Spectral response data",
           "",
           c(
             "photopic_sensitivity",
             "scotopic_sensitivity",
             "CIE1924_lef.spct",
             "CIE1951_scotopic_lef.spct",
             "CIE2008_lef2deg.spct",
             "SetlowTUV.spct"
           )
)
